@@ -96,6 +96,11 @@
 				      cargo_type => 'leaf',
 				      cargo_args => {value_type => 'string'},
 				    },
+	       [qw/ac_list/] => { type => 'list',
+				  cargo_type => 'leaf',
+				  auto_create_ids => 3,
+				  cargo_args => {value_type => 'string'},
+				},
 	       "list_XLeds" => { type => 'list',
 			    cargo_type => 'leaf',
 			    cargo_args => { value_type => 'integer', 
